MUSE_NB_CHANNELS = 5
MUSE_SAMPLING_RATE = 256
MUSE_SCAN_TIMEOUT = 10.5

MUSE_GATT_ATTR_STREAM_TOGGLE = '273e0001-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_TP9 = '273e0003-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_AF7 = '273e0004-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_AF8 = '273e0005-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_TP10 = '273e0006-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_RIGHTAUX = '273e0007-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_GYRO = '273e0009-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_ACCELEROMETER = '273e000a-4c4d-454d-96be-f03bac821358'
MUSE_GATT_ATTR_TELEMETRY = '273e000b-4c4d-454d-96be-f03bac821358'

MUSE_ACCELEROMETER_SCALE_FACTOR = 0.0000610352
MUSE_GYRO_SCALE_FACTOR = 0.0074768

AUTO_DISCONNECT_DELAY = 3

LSL_SCAN_TIMEOUT = 5  # How long to look for an LSL stream.
LSL_CHUNK = 12  # Chunk size.
LSL_BUFFER = 360  # Buffer length.

VIEW_SUBSAMPLE = 2
VIEW_BUFFER = 12



from setuptools import setup, find_packages
from shutil import copyfile
import os


def copy_docs():
    docs_dir = 'muselsl/docs'
    if not os.path.exists(docs_dir):
        os.makedirs(docs_dir)

    copyfile('README.md', docs_dir + '/README.md')
    #copyfile('blinks.png', docs_dir + '/blinks.png')


copy_docs()

setup(name='muselsl',
      version='1.0.1',
      description='Stream and visualize EEG data from the Muse 2016 headset.',
      keywords='muse lsl eeg ble neuroscience',
      url='https://github.com/alexandrebarachant/muse-lsl/',
      author='Alexandre Barachant',
      author_email='alexandre.barachant@gmail.com',
      license='BSD (3-clause)',
      entry_points={
          'console_scripts': [
              'muselsl=muselsl.cli:main',
          ],
      },
      packages=find_packages(),
      package_data={'muselsl': ['docs/README.md', 'docs/examples/*']},
      include_package_data=True,
      zip_safe=False,
      install_requires=['bitstring', 'pylsl', 'pygatt==3.1.1',
                        'pandas', 'scikit-learn', 'numpy', 'seaborn', 'pexpect'],
      extras_require={'Viewer V2': ['mne', 'vispy']},
      classifiers=[
          # How mature is this project?  Common values are
          #   3 - Alpha
          #   4 - Beta
          #   5 - Production/Stable
          'Development Status :: 4 - Beta',

          # Indicate who your project is intended for
          'Intended Audience :: Science/Research',
          'Topic :: Software Development',

          # Pick your license as you wish (should match "license" above)
          'License :: OSI Approved :: BSD License',

          # Specify the Python versions you support here.  In particular, ensure
          # that you indicate whether you support Python 2, Python 3 or both.
          'Operating System :: Microsoft :: Windows',
          'Operating System :: POSIX',
          'Operating System :: Unix',
          'Operating System :: MacOS',

          'Programming Language :: Python']
      )
